unit main;

interface

uses
  Forms, BFBaseComponent, BFIrDADiscovery, Menus, Classes, Controls,
  ComCtrls;

type
  TfmMain = class(TForm)
    MainMenu: TMainMenu;
    miFile: TMenuItem;
    miFileExit: TMenuItem;
    miView: TMenuItem;
    miViewRefresh: TMenuItem;
    miHelp: TMenuItem;
    miHelpAbout: TMenuItem;
    lvDiscovery: TListView;
    miSelectDevice: TMenuItem;
    N1: TMenuItem;
    lvMonitoring: TListView;
    miFileStartMonitoring: TMenuItem;
    miFileStopMonitoring: TMenuItem;
    N2: TMenuItem;
    BFIrDADiscovery: TBFIrDADiscovery;
    procedure miHelpAboutClick(Sender: TObject);
    procedure miFileExitClick(Sender: TObject);
    procedure miViewRefreshClick(Sender: TObject);
    procedure miSelectDeviceClick(Sender: TObject);
    procedure miFileStartMonitoringClick(Sender: TObject);
    procedure miFileStopMonitoringClick(Sender: TObject);
    procedure BFIrDADiscoveryFound(Sender: TObject; Device: TBFIrDADevice);
    procedure BFIrDADiscoveryLost(Sender: TObject; Device: TBFIrDADevice);
  end;

var
  fmMain: TfmMain = nil;

implementation

uses
  SysUtils;

{$R *.dfm}

procedure TfmMain.miHelpAboutClick(Sender: TObject);
begin
  BFIrDADiscovery.ShowAbout;
end;

procedure TfmMain.miFileExitClick(Sender: TObject);
begin
  Close;
end;

procedure TfmMain.miViewRefreshClick(Sender: TObject);
var
  DevList: TBFIrDADeviceList;
  Loop: Integer;
begin
  BFIrDADiscovery.Discovery(DevList);

  with lvDiscovery.Items do begin
    BeginUpdate;

    Clear;

    for Loop := 0 to DevList.Count - 1 do begin
      with Add do begin
        Caption := DevList[Loop].Name;

        SubItems.Add(DevList[Loop].Address);
        SubItems.Add(IntToStr(DevList[Loop].CharSet));
        SubItems.Add(IntToStr(DevList[Loop].Hints1));
        SubItems.Add(IntToStr(DevList[Loop].Hints2));
      end;
    end;

    EndUpdate;
  end;

  DevList.Free;
end;

procedure TfmMain.miSelectDeviceClick(Sender: TObject);
var
  Device: TBFIrDADevice;
begin
  Device := BFIrDADiscovery.SelectDevice;

  if Assigned(Device) then Device.Free;
end;

procedure TfmMain.miFileStartMonitoringClick(Sender: TObject);
begin
  BFIrDADiscovery.StartMonitoring;

  miFileStartMonitoring.Enabled := False;
  miFileStopMonitoring.Enabled := True;
end;

procedure TfmMain.miFileStopMonitoringClick(Sender: TObject);
begin
  BFIrDADiscovery.StopMonitoring;

  miFileStartMonitoring.Enabled := True;
  miFileStopMonitoring.Enabled := False;
end;

procedure TfmMain.BFIrDADiscoveryFound(Sender: TObject; Device: TBFIrDADevice);
begin
  with lvMonitoring.Items do begin
    BeginUpdate;

    with Add do begin
      Caption := 'Found';
      SubItems.Add(Device.Name);
      SubItems.Add(Device.Address);
      SubItems.Add(IntToStr(Device.CharSet));
      SubItems.Add(IntToStr(Device.Hints1));
      SubItems.Add(IntToStr(Device.Hints2));
    end;

    EndUpdate;
  end;
end;

procedure TfmMain.BFIrDADiscoveryLost(Sender: TObject; Device: TBFIrDADevice);
begin
  with lvMonitoring.Items do begin
      BeginUpdate;

    with Add do begin
      Caption := 'Lost';
      SubItems.Add(Device.Name);
      SubItems.Add(Device.Address);
      SubItems.Add(IntToStr(Device.CharSet));
      SubItems.Add(IntToStr(Device.Hints1));
      SubItems.Add(IntToStr(Device.Hints2));
    end;

    EndUpdate;
  end;
end;

end.
